@@ -3,7 +3,7 @@ package RPi::WiringPi::Core;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Carp qw(croak);
 
@@ -78,7 +78,10 @@ RPi::WiringPi::Core - wiringPi Core Functions
 
 =head1 DESCRIPTION
 
-This module provides Perl method access to the
+This is an XS-based module, and requires L<wiringPi|http://wiringpi.com> to be
+installed.
+
+It provides Perl method access to (at this time, most of) the
 L<wiringPi Core|http://wiringpi.com/reference/core-functions> along with a few
 of its system functions.
 
@@ -120,20 +123,6 @@ Mandatory: The GPIO pin number, using wiringPi's pin number representation.
 
 Mandatory: C<0> to have the pin listen on INPUT, and C<1> for OUTPUT.
 
-=head2 pull_up_down($pin, $direction)
-
-Enable/disable the built-in pull up/down resistors for a specified pin.
-
-Parameters:
-
-    $pin
-
-Mandatory: The wiringPi number representation of the GPIO pin.
-
-    $direction
-
-Mandatory: C<2> for UP, C<1> for DOWN and C<0> to disable the resistor.
-
 =head2 read_pin($pin);
 
 Returns the current state (HIGH/on, LOW/off) of a given pin.
@@ -158,6 +147,34 @@ Mandatory: The wiringPi number representation of the GPIO pin.
 
 Mandatory: C<1> to turn the pin on (HIGH), and C<0> to turn it LOW (off).
 
+=head2 pull_up_down($pin, $direction)
+
+Enable/disable the built-in pull up/down resistors for a specified pin.
+
+Parameters:
+
+    $pin
+
+Mandatory: The wiringPi number representation of the GPIO pin.
+
+    $direction
+
+Mandatory: C<2> for UP, C<1> for DOWN and C<0> to disable the resistor.
+
+=head2 pwm_write($pin, $value)
+
+Sets the Pulse Width Modulation duty cycle (on time) of the pin.
+
+Parameters:
+
+    $pin
+
+Mandatory: The wiringPi number representation of the GPIO pin.
+
+    $value
+
+Mandatory: C<0> to C<1024>. C<0> is 0% (off) and C<1024> is 100% (fully on).
+
 =head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
